@@ -32,6 +32,13 @@ __all__ = [
     "meta",
     "save_zip_db",
     "add_tabs",
+    "add_markdown",
+    "add_icon",
+    "affix",
+    "add_mermaid",
+    "add_input",
+    "add_numberSlider",
+    "add_svg_icon",
 ]
 
 add_tabs = app.add_tabs
@@ -55,3 +62,10 @@ _save_db = app.save_db
 save_zip_db = app.save_zip_db
 
 to_html = app.to_html
+add_markdown = app.add_markdown
+add_icon = app.add_icon
+add_svg_icon = app.add_svg_icon
+affix = app.affix
+add_mermaid = app.add_mermaid
+add_input = app.add_input
+add_numberSlider = app.add_numberSlider
