@@ -17,6 +17,13 @@ from pybi.core.components import (
     UploadComponent,
     GridBoxComponent,
     TabsComponent,
+    Markdown,
+    IconComponent,
+    SvgIconComponent,
+    AffixComponent,
+    Mermaid,
+    Input,
+    NumberSlider,
 )
 from pybi.core.components.reactiveComponent import EChart, Slicer, Table, TextValue
 from pybi.core.dataSource import (
@@ -28,11 +35,13 @@ from pybi.core.dataSource import (
 )
 from pybi.utils.dataSourceUtils import ds2sqlite_file_base64, ds2sqlite
 from pybi.utils.data_gen import (
-    json_dumps_fn,
+    JsonUtils,
     random_ds_name,
     random_dv_name,
     get_project_root,
 )
+from pybi.utils.markdown2 import markdown
+from pybi.core.uiResource import ResourceManager
 
 from pybi.core.sql import SqlInfo, SqlWrapper
 import pybi.utils.sql as sqlUtils
@@ -44,6 +53,8 @@ from pybi.core.components.reactiveComponent.echarts import (
     EChartJscode,
     OptionsExtractor,
 )
+import pybi.utils.pyecharts_utils as pyecharts_utils
+import pybi as pbi
 
 if TYPE_CHECKING:
     pass
@@ -86,6 +97,8 @@ class App(ContainerComponent):
         self.echartsRenderer = "canvas"
         self._doc_title = None
         self.__meta = AppMeta(self)
+        self.__json_utils = JsonUtils()
+        self.__resourceManager = ResourceManager()
 
     def __record_and_check_dataset_name(self, name: str):
         if name in self.__dataSetNames:
@@ -169,6 +182,7 @@ class App(ContainerComponent):
         host = host or self._get_temp_host() or self
         host._add_children(cp)
 
+        self.__resourceManager.register_element_cps()
         return cp
 
     def add_text(
@@ -215,6 +229,7 @@ class App(ContainerComponent):
         host = host or self._get_temp_host() or self
         host._add_children(cp)
 
+        self.__resourceManager.register_element_cps()
         return cp
 
     def add_table(
@@ -234,6 +249,7 @@ class App(ContainerComponent):
         host = host or self._get_temp_host() or self
         host._add_children(cp)
 
+        self.__resourceManager.register_element_cps()
         return cp
 
     def add_echart(
@@ -244,29 +260,38 @@ class App(ContainerComponent):
     ):
         cp = None
 
-        if isinstance(options, (BaseChart, ChartCollector)):
+        if not isinstance(options, (BaseChart, ChartCollector, dict)):
+            from pyecharts.charts.base import Base
 
-            if isinstance(options, BaseChart):
-                options = ChartCollector().append(options)
+            if isinstance(options, Base):
+                options = options.get_options()
+                assert isinstance(options, dict)
+                pyecharts_utils.replace_jscode(options)
+                #
+                self.__json_utils.mark_pyecharts()
+
+        if isinstance(options, (BaseChart, ChartCollector)):
+            opts = options
+
+            if isinstance(opts, BaseChart):
+                opts = ChartCollector().append(opts)
 
             cp = EChart(option_type="dict")
 
             if (
-                len(options._collector) > 1
+                len(opts._collector) > 1
                 and easy_echarts._settings.drill_down_default_set_click_filter
             ):
-                for chart in options._collector:
+                for chart in opts._collector:
                     chart._create_default_click_filter()
 
-            for chart in options._collector:
-                options, updateInfos = chart.get_options_infos()
+            for chart in opts._collector:
+                opts, updateInfos = chart.get_options_infos()
 
                 ds_infos = []
                 jscodes = []
 
-                OptionsExtractor.extract_and_remove_from_dict(
-                    options, ds_infos, jscodes
-                )
+                OptionsExtractor.extract_and_remove_from_dict(opts, ds_infos, jscodes)
 
                 ds_infos = [
                     EChartDatasetInfo({}, path, sql._sql_info) for path, sql in ds_infos
@@ -274,10 +299,10 @@ class App(ContainerComponent):
 
                 jscodes = [EChartJscode(path, jscode) for path, jscode in jscodes]
 
-                info = EChartInfo(options, ds_infos, updateInfos, jscodes)
+                info = EChartInfo(opts, ds_infos, updateInfos, jscodes)
                 cp._add_chart_info(info)
 
-        else:
+        elif isinstance(options, dict):
             cp = EChart(option_type="dict")
 
             ds_infos = []
@@ -295,8 +320,11 @@ class App(ContainerComponent):
             cp._add_chart_info(info)
 
         host = host or self._get_temp_host() or self
+
+        assert cp is not None
         host._add_children(cp)
 
+        self.__resourceManager.register_echarts()
         return cp
 
     def flowBox(
@@ -353,18 +381,15 @@ class App(ContainerComponent):
     def add_tabs(
         self,
         names: List[str],
-        mode="narrowing",
         *,
         host: Optional[ContainerComponent] = None,
     ):
-        """
-        mode: 'fullWidth' | 'narrowing'
-            fullWidth:全宽度;页签栏会横向撑满屏幕宽度
-            narrowing(默认值):收窄;页签栏向左靠拢
-        """
-        cp = TabsComponent(names, mode, appHost=self)
+        """ """
+        cp = TabsComponent(names, appHost=self)
         host = host or self._get_temp_host() or self
         host._add_children(cp)
+
+        self.__resourceManager.register_element_cps()
         return cp
 
     def save_zip_db(self, path: str):
@@ -384,6 +409,8 @@ class App(ContainerComponent):
         )
         if self._doc_title:
             data["docTitle"] = self._doc_title
+
+        data["version"] = pbi.__version__
         return data
 
     def __reset_data(self):
@@ -392,14 +419,15 @@ class App(ContainerComponent):
         self.dataSources = []
         self.dataViews = []
 
-    def to_json(self):
-        return json_dumps_fn(self, indent=2, ensure_ascii=False)
+    def to_json(self, *args, **kws):
+        return self.__json_utils.dumps(self, *args, **kws)
+        # return json_dumps_fn(self, indent=2, ensure_ascii=False)
 
     def to_raw_html(self):
         try:
             symbol = '"__{{__config_data__}}___"'
 
-            config = json_dumps_fn(self, ensure_ascii=False)
+            config = self.__json_utils.dumps(self)
 
             with open(
                 get_project_root() / "template/index.html", mode="r", encoding="utf8"
@@ -413,8 +441,10 @@ class App(ContainerComponent):
 
     def to_html(self, file, display_output_path=False):
         try:
-            file = Path(file)
-            raw = self.to_raw_html()
+            # file = Path(file)
+            # raw = self.to_raw_html()
+
+            raw = self.__resourceManager.build_html(self.to_json())
             Path(file).write_text(raw, "utf8")
 
             if display_output_path:
@@ -423,3 +453,139 @@ class App(ContainerComponent):
             raise e
         else:
             self.__reset_data()
+
+    def add_markdown(
+        self,
+        md: str,
+        *,
+        host: Optional[ContainerComponent] = None,
+    ):
+        # if isinstance(md, SqlWrapper):
+        #     md = str(md)
+        md = SqlInfo.around_backticks(md)
+
+        html = markdown(
+            md,
+            extras=[
+                "fenced-code-blocks",
+                "target-blank-links",
+                "task_list",
+                "code-color",
+                "tag-friendly",
+            ],
+        )
+
+        contents = list(SqlInfo.extract_sql_from_text(html))
+
+        cp = Markdown(contents)
+
+        host = host or self._get_temp_host() or self
+        host._add_children(cp)
+
+        return cp
+
+    def add_icon(
+        self,
+        icon: str,
+        size="2em",
+        color="currentColor",
+        *,
+        host: Optional[ContainerComponent] = None,
+    ):
+
+        cp = IconComponent(icon, size, color)
+
+        host = host or self._get_temp_host() or self
+        host._add_children(cp)
+
+        return cp
+
+    def add_svg_icon(
+        self,
+        svg: str,
+        size="2em",
+        color="currentColor",
+        *,
+        host: Optional[ContainerComponent] = None,
+    ):
+
+        cp = SvgIconComponent(svg, size, color)
+
+        host = host or self._get_temp_host() or self
+        host._add_children(cp)
+
+        return cp
+
+    def affix(
+        self,
+        *,
+        host: Optional[ContainerComponent] = None,
+    ):
+        cp = AffixComponent(self)
+        host = host or self._get_temp_host() or self
+        host._add_children(cp)
+
+        self.__resourceManager.register_element_cps()
+        return cp
+
+    def add_mermaid(
+        self,
+        graph: str,
+        *,
+        host: Optional[ContainerComponent] = None,
+    ):
+        """
+        [mermaid文档](https://github.com/mermaid-js/mermaid/blob/develop/README.zh-CN.md)
+        ---
+        >>> graph = '''
+        flowchart LR
+        A[Hard] -->|Text| B(Round)
+        B --> C{Decision}
+        C -->|One| D[Result 1]
+        C -->|Two| E[Result 2]
+        '''
+        >>> add_mermaid(graph)
+        """
+        cp = Mermaid(graph)
+        host = host or self._get_temp_host() or self
+        host._add_children(cp)
+
+        self.__resourceManager.register_mermaid_cps()
+        return cp
+
+    def add_input(
+        self,
+        data: DataSourceTable,
+        field: str,
+        where_expr="like '%${}%'",
+        *,
+        host: Optional[ContainerComponent] = None,
+    ):
+        """ """
+        cp = Input(where_expr).add_updateInfo(data.source_name, field)
+        host = host or self._get_temp_host() or self
+        host._add_children(cp)
+
+        self.__resourceManager.register_element_cps()
+        return cp
+
+    def add_numberSlider(
+        self,
+        data: DataSourceTable,
+        field: str,
+        where_expr=" between ${0} and ${1}",
+        range=True,
+        *,
+        host: Optional[ContainerComponent] = None,
+    ):
+        """ """
+        cp = (
+            NumberSlider(where_expr)
+            .add_updateInfo(data.source_name, field)
+            .set_props({"range": range})
+        )
+        host = host or self._get_temp_host() or self
+        host._add_children(cp)
+
+        self.__resourceManager.register_element_cps()
+        return cp
