@@ -1,2 +1,2 @@
 from pybi.core.dataSource import DataSource, DataView
-from .sql import Sql
+from .sql import SqlInfo
