@@ -1,5 +1,5 @@
 from __future__ import annotations
-from typing import TYPE_CHECKING, List, Optional, Union
+from typing import TYPE_CHECKING, List, Optional, Union, Dict
 
 
 from pybi.utils.data_gen import Jsonable, get_global_id
@@ -18,11 +18,25 @@ class Component(Jsonable):
         self._styles: List[Style] = []
         self.visible: Union[bool, SqlWrapper] = True
         self.__gridArea: str = ""
+        self._props = {}
+        self.classes = []
+
+    def set_props(self, props: Dict):
+        self._props.update(props)
+        return self
 
     def set_debugTag(self, tag: str):
         self._debugTag = tag
         return self
 
+    def set_classes(self, value: str):
+        """
+        set_classes('text-primary bg-positive')
+        """
+        values = (v for v in value.split(" ") if v)
+        self.classes.extend(values)
+        return self
+
     def set_gridArea(self, area_name: str):
         self.__gridArea = area_name
         return self
@@ -41,6 +55,8 @@ class Component(Jsonable):
             data["gridArea"] = self.__gridArea
 
         data["debugTag"] = self._debugTag
+        data["props"] = self._props
+        data["classes"] = list(dict.fromkeys(data["classes"]).keys())
 
         return data
 
