@@ -1,5 +1,5 @@
 from __future__ import annotations
-from typing import TYPE_CHECKING, Union, List, Optional
+from typing import TYPE_CHECKING, Dict, Union, List, Optional
 
 from .componentTag import ComponentTag
 from .component import Component
@@ -168,9 +168,7 @@ class ColBoxComponent(ContainerComponent):
 
 
 class TabsComponent(ContainerComponent):
-    def __init__(
-        self, names: List[str], mode="narrowing", appHost: Optional[App] = None
-    ) -> None:
+    def __init__(self, names: List[str], appHost: Optional[App] = None) -> None:
         """
         mode: 'fullWidth' | 'narrowing'
         """
@@ -178,7 +176,11 @@ class TabsComponent(ContainerComponent):
         if len(names) > len(set(names)):
             raise Exception("names cannot be duplicated")
         self.names = names
-        self.mode = mode
+        self.icons = []
+        self.tabsProps = {}
+        self.panelsProps = {}
+        self.tabsClasses: List[str] = []
+        self.panelsClasses: List[str] = []
 
         self.__name2idx = {name: idx for idx, name in enumerate(self.names)}
 
@@ -194,3 +196,49 @@ class TabsComponent(ContainerComponent):
         res = self.children[idx]
         assert isinstance(res, ContainerComponent)
         return res
+
+    def set_icons(self, icons: List[str]):
+        self.icons = icons
+
+        self.set_tabsProps({"inline-label": len(icons) > 0})
+        return self
+
+    def set_tabsProps(self, props: Dict):
+        self.tabsProps.update(props)
+        return self
+
+    def set_panelsProps(self, props: Dict):
+        self.panelsProps.update(props)
+        return self
+
+    def set_tabsClasses(self, value: str):
+        """
+        set_tabsClasses('text-primary bg-positive')
+        """
+        values = (v for v in value.split(" ") if v)
+        self.tabsClasses.extend(values)
+        return self
+
+    def set_panelsClasses(self, value: str):
+        """
+        set_panelsClasses('text-primary bg-positive')
+        """
+        values = (v for v in value.split(" ") if v)
+        self.panelsClasses.extend(values)
+        return self
+
+    def set_props(self, props: Dict):
+        return self.set_tabsProps(props)
+
+    def _to_json_dict(self):
+        data = super()._to_json_dict()
+        data["tabsClasses"] = list(dict.fromkeys(data["tabsClasses"]).keys())
+        data["panelsClasses"] = list(dict.fromkeys(data["panelsClasses"]).keys())
+        return data
+
+
+
+class AffixComponent(ContainerComponent):
+    def __init__(self, appHost: Optional[App] = None) -> None:
+        super().__init__(ComponentTag.Affix, appHost)
+
