@@ -6,7 +6,7 @@ from pybi.utils.data_gen import Jsonable
 from pybi.core.components import ComponentTag
 from .base import ReactiveComponent
 from pybi.core.dataSource import DataSourceTable
-
+import pybi.utils.echarts_opts_utils as echarts_opts_utils
 
 if TYPE_CHECKING:
     from pybi.core.dataSource import DataSourceTable
@@ -79,21 +79,7 @@ class OptionsExtractor:
         out_datasets: List[tuple[str, SqlWrapper]],
         out_jscodes: List[tuple[str, str]],
     ):
-        stack = [(data, "")]
-
-        while len(stack) > 0:
-            target, path = stack.pop()
-
-            if isinstance(target, dict):
-                inputs = ((value, f"{path}.{key}") for key, value in target.items())
-                stack.extend(inputs)
-                continue
-
-            if isinstance(target, list):
-                inputs = ((value, f"{path}[{idx}]") for idx, value in enumerate(target))
-                stack.extend(inputs)
-                continue
-
+        for target, path in echarts_opts_utils.iter_each_items(data):
             if isinstance(target, SqlWrapper):
                 rpath = path[1:]
                 out_datasets.append((rpath, target))
@@ -123,29 +109,7 @@ class OptionsExtractor:
         """
         path: 'sreies[0].data[0].item.value'
         """
-        paths = path.split(".")
-        target = options
-        for path in paths[:-1]:
-            if path[-1] == "]":
-                # e.g sreies[0]
-                start_idx = path.index("[")
-                key = path[:start_idx]
-                path_idx = int(path[start_idx + 1 : -1])
-                target = target[key][path_idx]
-            else:
-                # e.g .item
-                target = target[path]
-
-        path = paths[-1]
-        if path[-1] == "]":
-            # e.g sreies[0]
-            start_idx = path.index("[")
-            key = path[:start_idx]
-            path_idx = int(path[start_idx + 1 : -1])
-            target[key][path_idx] = None
-        else:
-            # e.g .item
-            target[path] = None
+        echarts_opts_utils.set_prop_by_path(options, path, None)
 
 
 class EChartInfo(Jsonable):
