@@ -1,5 +1,5 @@
 from __future__ import annotations
-from typing import TYPE_CHECKING, List, Union
+from typing import TYPE_CHECKING, List, Dict
 
 
 from pybi.core.components import ComponentTag
@@ -23,3 +23,11 @@ class Slicer(SingleReactiveComponent):
     def set_multiple(self, multiple: bool):
         self.multiple = multiple
         return self
+
+    def set_props(self, props: Dict):
+        """
+        [slicer props](https://element-plus.gitee.io/zh-CN/component/select.html#select-attributes)
+        e.g
+        >>> .add_slicer(...).set_props({'placeholder':'my define placeholder'})
+        """
+        return super().set_props(props)
