@@ -12,14 +12,29 @@ if TYPE_CHECKING:
 __all__ = ["easy_echarts"]
 
 
+class EasyEChartsSettings:
+    def __init__(self) -> None:
+        self.drill_down_default_set_click_filter = True
+
+
 class EasyEChartsMeta:
+    def __init__(self) -> None:
+        self._settings = EasyEChartsSettings()
+
+    def off_drill_down_default_set_click_filter(self):
+        """
+        默认情况下,多个组合图表配置会自动为其每个图表添加 `click_filter` 联动。
+        此函数调用后,会关闭其功能
+        """
+        self._settings.drill_down_default_set_click_filter = False
+
     def make_line(
         self,
         data: DataSourceTable,
         x: str,
         y: str,
         color: Optional[str] = None,
-        agg="avg",
+        agg="round(avg(${}),2)",
     ):
         return LineChart(data, x, y, color, agg)
 
@@ -30,7 +45,7 @@ class EasyEChartsMeta:
         x: str,
         y: str,
         color: Optional[str] = None,
-        agg="avg",
+        agg="round(avg(${}),2)",
     ):
         return BarChart(data, x, y, color, agg)
 
@@ -40,7 +55,7 @@ class EasyEChartsMeta:
         *,
         name: str,
         value: str,
-        agg="avg",
+        agg="round(avg(${}),2)",
     ):
         return PieChart(data, name, value, agg)
 
@@ -51,7 +66,7 @@ class EasyEChartsMeta:
         x: str,
         y: str,
         color: Optional[str] = None,
-        agg="avg",
+        agg="round(avg(${}),2)",
     ):
         return ScatterChart(data, x, y, color, agg)
 
