@@ -1,11 +1,12 @@
 from __future__ import annotations
-from typing import TYPE_CHECKING, Dict, Tuple, List, Sequence, Union
+from typing import TYPE_CHECKING, Dict, Tuple, List, Any, Union
 
 from pybi.core.components.reactiveComponent.echarts import EChartUpdateInfo
 from pybi.core.dataSource import DataSourceTable
-
+import pybi.utils.echarts_opts_utils as echarts_opts_utils
+import copy
 if TYPE_CHECKING:
-    from pybi.core.components.reactiveComponent import EChartDatasetInfo
+    pass
 
 m_merge_keys = set(["legend", "title", "grid", "series"])
 
@@ -21,6 +22,7 @@ class BaseChart:
         }
         self.__merge_opt = {}
         self._updateInfos: List[EChartUpdateInfo] = []
+        self._prop_by_paths: List[Tuple[str, Any]] = []
 
     def __add__(self, other: BaseChart):
         return ChartCollector().append(self).append(other)
@@ -31,7 +33,7 @@ class BaseChart:
 
     def get_options(self):
         return {
-            **self.__base_opt,
+            **copy.deepcopy(self.__base_opt),
             **{k: v for k, v in self.__merge_opt.items() if k in m_merge_keys},
         }
 
@@ -87,6 +89,18 @@ class BaseChart:
     ) -> Tuple[Dict, List[EChartUpdateInfo]]:
         raise NotImplementedError
 
+    def set_prop_by_path(self, path: str, value):
+        """
+        >>> .set_prop_by_path('xAxis[0].axisLabel.interval',1)
+        """
+        self._prop_by_paths.append((path, value))
+        return self
+
+    def _update_props_by_path(self, opts: Dict):
+
+        for path, value in self._prop_by_paths:
+            echarts_opts_utils.set_prop_by_path(opts, path, value)
+
 
 class ChartCollector:
     def __init__(self) -> None:
